#!/usr/bin/env bash
echo "$@"
